@@ -13,11 +13,12 @@
 #'
 #' @details
 #' Suppose that \code{g} is an undirected and connected graph consisting of
-#' \eqn{n} vertices \eqn{v_1,\dots,v_n} whose multiplicities (weights) are
-#' \eqn{\eta_1,\dots,\eta_n > 0}, respectively.
+#' \eqn{n} vertices \ifelse{html}{\out{<i>v<sub>1</sub></i>, ..., <i>v<sub>n</sub></i>}}{{\eqn{v_1,\dots,v_n}}}
+#' whose multiplicities (weights) are \eqn{\eta_1,\dots,\eta_n > 0}, respectively.
 #'
 #' The median of this graph is the node minimizing the weighted sum of distances
-#' (Hakimi 1964). That is, \eqn{v_i} is the median node if
+#' (Hakimi 1964). That is,
+#' \ifelse{html}{\out{<i>v<sub>i</sub></i>}}{{\eqn{v_i}}} is the median node if
 #' \deqn{
 #'  \sum_{k=1}^{n} \eta_k d(v_i, v_k)
 #' }
@@ -46,11 +47,11 @@
 #' @param g An \code{igraph} graph object or a distance matrix. The graph must
 #'   be undirected and connected. Equivalently, the distance matrix must be
 #'   symmetric, and all entries must be finite.
-#' @param eta An optional positive multiplicity (weight) vector for (vertex)
-#'   weighted networks. If set to \code{NULL} (the default), all vertices will
-#'   have the same weight (multiplicity), i.e., \code{g} is treated as an
-#'   unweighted graph. The length of the \code{eta} must be equivalent to the
-#'   number of vertices.
+#' @param eta An optional nonnegative multiplicity (weight) vector for (vertex)
+#'   weighted networks. The sum of its components must be positive. If set to
+#'   \code{NULL} (the default), all vertices will have the same positive weight
+#'   (multiplicity), i.e., \code{g} is treated as a vertex unweighted graph. The
+#'   length of the \code{eta} must be equivalent to the number of vertices.
 #' @return A numeric vector whose length is equivalent to the number of vertices
 #'   in the graph \code{g}. Each component of the vector is the
 #'   \ifelse{html}{\out{<i>L</i><sub>1</sub>}}{{\eqn{L_1}}} centrality of each
@@ -103,9 +104,10 @@ L1cent.matrix <- function(g, eta = NULL) {
 
   n <- ncol(g)
   geta1 <- matrix(rep(colSums(g *eta),n), ncol = n)
-  rep(1, n) - 1 / sum(eta) *
+  res <- rep(1, n) - 1 / sum(eta) *
     apply((geta1 - t(geta1)) / (g + diag(rep(Inf, n))), 1,
           function(r) max(c(r, 0)))
+  pmin(pmax(res,0),1)
 }
 
 
@@ -156,17 +158,3 @@ Lorenz_plot <- function(x, add = FALSE, ...){
   }
   invisible(unname(1 - 2*(Fx[2])*(sum(Deltax)-1/2))) # Gini index
 }
-
-#' #' @name Extract.L1cent
-#' #' @title Extract or Replace Parts of a L1cent Object
-#' #'
-#' #' @description
-#' #' Extract or Replace subsets of a L1cent Object
-#' #' @param x A \code{L1cent} object.
-#' #' @param ... A specification of indices -- see [base::Extract].
-#' #' @return A \code{L1cent} object.
-#' #' @export
-#' #' @keywords internal
-#' `[.L1cent` <- function(x, ...){
-#'   structure(unclass(x)[...], class="L1cent")
-#' }
