@@ -82,8 +82,14 @@ L1centLOC.matrix <- function(g, eta = NULL, alpha){
       lapply(NB, function(l)
         which(l >= stats::quantile(l, 1 - m[i] / n)))
     loc.cent[[i]] <-
-      sapply(1:length(nb.index), function(j)
-        L1cent(g[nb.index[[j]], nb.index[[j]]], eta = eta[nb.index[[j]]])[names(nb.index)[j]])
+      sapply(1:length(nb.index), function(j){
+        index <- which(rownames(g.new <- g[nb.index[[j]], nb.index[[j]]]) == names(nb.index)[j])
+        closenessinv <- colSums((eta.new <- eta[nb.index[[j]]])*g.new)
+        1 - max((closenessinv[index] - closenessinv)/(g.new + diag(Inf,nrow(g.new)))[index,]/sum(eta.new))
+      })
+    names(loc.cent[[i]]) <- rownames(g)
   }
   return(loc.cent)
 }
+
+
